@@ -1,14 +1,14 @@
 """Browser module - Abstract base classes for browser automation."""
 
 from .browser import Browser
-from .session import Session
+from .context import Context
 from .page import Page
 from .element import Element
 from .cookies import Cookie, Cookies
 
 __all__ = [
     "Browser",
-    "Session",
+    "Context",
     "Page",
     "Element",
     "Cookie",
