@@ -1,13 +1,13 @@
 """Playwright browser integration."""
 
 from .playwright_browser import PlaywrightBrowser
-from .playwright_session import PlaywrightSession
+from .playwright_context import PlaywrightContext
 from .playwright_page import PlaywrightPage
 from .playwright_element import PlaywrightElement
 
 __all__ = [
     "PlaywrightBrowser",
-    "PlaywrightSession",
+    "PlaywrightContext",
     "PlaywrightPage",
     "PlaywrightElement",
 ]
